------------------------------------------------------------------------------
--                                                                          --
--                         GNAT COMPILER COMPONENTS                         --
--                                                                          --
--                              E X P _ C H 8                               --
--                                                                          --
--                                 B o d y                                  --
--                                                                          --
--                            $Revision: 1.6 $                              --
--                                                                          --
--     Copyright (C) 1992,1993,1994,1995 Free Software Foundation, Inc.     --
--                                                                          --
-- GNAT is free software;  you can  redistribute it  and/or modify it under --
-- terms of the  GNU General Public License as published  by the Free Soft- --
-- ware  Foundation;  either version 2,  or (at your option) any later ver- --
-- sion.  GNAT is distributed in the hope that it will be useful, but WITH- --
-- OUT ANY WARRANTY;  without even the  implied warranty of MERCHANTABILITY --
-- or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License --
-- for  more details.  You should have  received  a copy of the GNU General --
-- Public License  distributed with GNAT;  see file COPYING.  If not, write --
-- to  the Free Software Foundation,  59 Temple Place - Suite 330,  Boston, --
-- MA 02111-1307, USA.                                                      --
--                                                                          --
-- GNAT was originally developed  by the GNAT team at  New York University. --
-- It is now maintained by Ada Core Technologies Inc (http://www.gnat.com). --
--                                                                          --
------------------------------------------------------------------------------

with Atree;    use Atree;
with Einfo;    use Einfo;
with Exp_Util; use Exp_Util;
with Exp_Ch6;  use Exp_Ch6;
with Itypes;   use Itypes;
with Nlists;   use Nlists;
with Nmake;    use Nmake;
with Sem_Util; use Sem_Util;
with Sinfo;    use Sinfo;

package body Exp_Ch8 is

   ------------------------------------------
   -- Expand_N_Object_Renaming_Declaration --
   ------------------------------------------

   --  Expression_Actions appearing in the Name field must be split as in
   --  Object declarations (see Expand_N_Object_Declaration for details)

   procedure Expand_N_Object_Renaming_Declaration (N : Node_Id) is
      Loc : constant Source_Ptr := Sloc (N);
      Nam : Node_Id := Name (N);

   begin
      if Nkind (Nam) = N_Expression_Actions then
         Insert_List_Before (N, Actions (Nam));

         if Present (First_Itype (Nam)) then
            declare
               Inode : constant Node_Id := Make_Implicit_Types (Loc);

            begin
               Transfer_Itypes (From => Nam, To => Inode);
               Insert_Before (N, Inode);
            end;
         end if;

         Nam := Expression (Nam);
         Set_Name (N, Nam);
         Set_Renamed_Object (Defining_Identifier (N), Nam);
      end if;

   end Expand_N_Object_Renaming_Declaration;

   ----------------------------------------------
   -- Expand_N_Subprogram_Renaming_Declaration --
   ----------------------------------------------

   --  Same processing as for N_Subprogram_Declaration

   procedure Expand_N_Subprogram_Renaming_Declaration (N : Node_Id) is
   begin
      if No (Corresponding_Spec (N)) then
         Make_Default_Expr_Functions (N,
           Defining_Unit_Simple_Name (Specification (N)));
      end if;
   end Expand_N_Subprogram_Renaming_Declaration;

end Exp_Ch8;
